Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LastJob ¶
type LastJob struct {
Level string `json:"level"`
JobBytes int `json:"job-bytes"`
JobFiles int `json:"job-files"`
JobErrors int `json:"job-errors"`
JobDate time.Time `json:"job-date"`
}
LastJob models query results for job metrics
type ScheduledJob ¶
type ScheduledJob struct {
ScheduledJobs int `json:"scheduled-jobs"`
}
ScheduledJob models query result of the time a job is about to be executed
type TotalBytes ¶
type TotalBytes struct {
Bytes int `json:"files"`
}
TotalBytes models query result of saved bytes sum for a server
type TotalFiles ¶
type TotalFiles struct {
Files int `json:"files"`
}
TotalFiles models query result of saved files sum for a server
Click to show internal directories.
Click to hide internal directories.